@@ -1,4 +1,4 @@
-      INCLUDE 'TSSS_f.h'
+      INCLUDE 'TSSS.h'
 C------------------------------------------------- 
 C     ARCOEF  ---  arfit, armaft, season, tvar
 C     FOUGER  ---  spgrh, tvar
@@ -7,7 +7,9 @@ C     REGRES  ---  lsqr, arfit, lsar1, lsar2, polreg
 C     COMAIC  ---  lsqr, arfit, lsar1, lsar2, polreg
 C     HUSHLD  ---  lsqr, arfit, marlsq, lsar1, lsar2 
 C     RECOEF  ---  lsqr, arfit, lsar1, lsar2, polreg
-C     REDUCT  ---  lsqr, arfit, lsar1, lsar2, polreg
+C     REDUCT  ---  arfit, lsar1, lsar2
+CC     REDUCT1  ---  polreg (polregf.f)
+CC     REDUCT2  ---  lsqr (lsqrf.f)
 C     SETXAR  ---  arfit, lsar1, lsar2
 C     ARYULE  ---  arma, arfit
 C     ARMASP  ---  arma, arfit, lsar1, tvspc
@@ -51,8 +53,8 @@ C
 cxx      IMPLICIT  REAL*8(A-H,O-Z)
 cc      DIMENSION  PAR(K), A(K), AA(50)
 cxx      DIMENSION  PAR(K), A(K), AA(K)
-      INTEGER :: K
-      REAL(8) :: PAR(K), A(K), AA(K)
+      INTEGER K
+      DOUBLE PRECISION PAR(K), A(K), AA(K)
 C
       DO 30  II=1,K
       A(II)  = PAR(II)
@@ -91,9 +93,9 @@ C          FB(I):  SINE TRANSFORM OF G  (I=0,1,...,LF)
 C
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cxx      DIMENSION G(LGP1),FC(LF1),FS(LF1)
-      INTEGER :: LGP1, LF1
-      REAL(8) :: G(LGP1),FC(LF1),FS(LF1)
-      REAL(8) :: PI, ALF, T, AK, TK, CK, SK, CK2, UM0, UM1, UM2
+      INTEGER LGP1, LF1
+      DOUBLE PRECISION G(LGP1),FC(LF1),FS(LF1)
+      DOUBLE PRECISION PI, ALF, T, AK, TK, CK, SK, CK2, UM0, UM1, UM2
       LG=LGP1-1
       LF=LF1-1
 C     REVERSAL OF G(I),I=1,...,LGP1 INTO G(LG3-I)   LG3=LGP1+1
@@ -146,9 +148,9 @@ C
 cxx      IMPLICIT  REAL*8(A-H,O-Z)
 cc      DIMENSION  A(K), PAR(K), G(50)
 cxx      DIMENSION  A(K), PAR(K), G(K)
-      INTEGER :: K
-      REAL(8) :: A(K), PAR(K)
-      REAL(8) :: G(K), S
+      INTEGER K
+      DOUBLE PRECISION A(K), PAR(K)
+      DOUBLE PRECISION G(K), S
 C
       DO 10  I=1,K
 cxx   10 PAR(I) = A(I)
@@ -197,9 +199,9 @@ C
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cc      DIMENSION  X(MJ1,1), A(MJ2,MJ2), SIG2(0:MJ2), AIC(0:MJ2)
 cxx      DIMENSION  X(MJ1,K+1), A(K,K), SIG2(0:K), AIC(0:K)
-      INTEGER :: K, N, MJ1, IMIN
-      REAL(8) :: X(MJ1,K+1), A(K,K), SIG2(0:K), AIC(0:K)
-      REAL(8) :: AICM
+      INTEGER K, N, MJ1, IMIN
+      DOUBLE PRECISION X(MJ1,K+1), A(K,K), SIG2(0:K), AIC(0:K)
+      DOUBLE PRECISION AICM
 C
       A(1:K, 1:K) = 0.0D0
 C
@@ -235,9 +237,9 @@ C
 cxx      IMPLICIT  REAL*8(A-H,O-Z)
 cc      DIMENSION  X(MJ1,1), AIC(0:K), SIG2(0:K)
 cxx      DIMENSION  X(MJ1,K+1), AIC(0:K), SIG2(0:K)
-      INTEGER :: N, K, MJ1
-      REAL(8) :: X(MJ1,K+1), SIG2(0:K), AIC(0:K)
-      REAL(8) :: PI2, PVAR
+      INTEGER N, K, MJ1
+      DOUBLE PRECISION X(MJ1,K+1), SIG2(0:K), AIC(0:K)
+      DOUBLE PRECISION PI2, PVAR
       DATA  PI2/6.28318531D0/
 C
       PVAR = 0.0D0
@@ -269,9 +271,9 @@ C
 cxx      IMPLICIT  REAL*8(A-H,O-Z)
 cc      DIMENSION  X(MJ1,1), D(MJ1)
 cxx      DIMENSION  X(MJ1,K), D(MJ1)
-      INTEGER :: MJ1, N, K
-      REAL(8) :: X(MJ1,K)
-      REAL(8) :: D(MJ1), TOL, H, G, F, S
+      INTEGER MJ1, N, K
+      DOUBLE PRECISION X(MJ1,K)
+      DOUBLE PRECISION D(MJ1), TOL, H, G, F, S
 C
       TOL = 1.0D-60
 C
@@ -330,9 +332,9 @@ C
 cxx      IMPLICIT REAL*8 (A-H,O-Z)
 cc      DIMENSION  X(MJ,1), A(1)
 cxx      DIMENSION  X(MJ,K+1), A(M)
-      INTEGER :: M, K, MJ
-      REAL(8) :: X(MJ,K+1), A(M)
-      REAL(8) :: SUM
+      INTEGER M, K, MJ
+      DOUBLE PRECISION X(MJ,K+1), A(M)
+      DOUBLE PRECISION SUM
 C
       A(M) = X(M,K+1)/X(M,M)
 c-----
@@ -351,53 +353,6 @@ C
       RETURN
       E N D
 C
-C
-cc      SUBROUTINE  REDUCT( SETX,Z,D,NMK,N0,K,MJ1,X )
-      SUBROUTINE  REDUCT1( SETX,Z,NMK,N0,K,MJ1,X )
-C
-C  ...  Successive Householder reduction  ...
-C
-C     Inputs:
-C        SETX:    Name of the subroutine for making X(I,J)
-C        Z(I):    Data vector
-C        D(I):    Working area
-C        NMK:     Number of actually used observations
-C        N0:      Time point of the previous set ofobservations
-C        K:       Heighest order of the model
-C        MJ1:     Adjustable dimension of X
-C     Output:
-C        X(I,J):  data matrix
-C
-cxx      IMPLICIT  REAL*8( A-H,O-Z )
-cc      DIMENSION  X(MJ1,1) , D(1), Z(1)
-cx      DIMENSION  X(MJ1,1) , Z(1)
-cxx      DIMENSION  X(MJ1,K+1) , Z(N0+NMK)
-      INTEGER :: NMK, N0, K, MJ1
-      REAL(8) :: Z(N0+NMK), X(MJ1,K+1)
-C
-      L = MIN0( NMK,MJ1 )
-      K1 = K + 1
-      N1 = L
-C
-      CALL  SETX( Z,N0,L,K,MJ1,0,X )
-cc      CALL  HUSHLD( X,D,MJ1,L,K1 )
-      CALL  HUSHLD( X,MJ1,L,K1 )
-      IF( N1 .GE. NMK )  RETURN
-C
-   10 L = MIN0( NMK-N1,MJ1-K1 )
-C
-      LK = L + K1
-      N2 = N0 + N1
-      CALL  SETX( Z,N2,L,K,MJ1,1,X )
-cc      CALL  HUSHLD( X,D,MJ1,LK,K1 )
-      CALL  HUSHLD( X,MJ1,LK,K1 )
-      N1 = N1 + L
-      IF( N1.LT.NMK )  GO TO 10
-C
-      RETURN
-C
-      E N D
-C
 C
       SUBROUTINE  REDUCT( SETX,Z,NMK,N0,K,MJ1,X )
 C
@@ -418,8 +373,8 @@ cxx      IMPLICIT  REAL*8( A-H,O-Z )
 cc      DIMENSION  X(MJ1,1) , D(1), Z(1)
 cx      DIMENSION  X(MJ1,1) , Z(1)
 cxx      DIMENSION  X(MJ1,K+1) , Z(N0+NMK+K)
-      INTEGER :: NMK, N0, K, MJ1
-      REAL(8) :: Z(N0+NMK+K), X(MJ1,K+1)
+      INTEGER NMK, N0, K, MJ1
+      DOUBLE PRECISION Z(N0+NMK+K), X(MJ1,K+1)
 C
       L = MIN0( NMK,MJ1 )
       K1 = K + 1
@@ -463,8 +418,8 @@ C        X(I,J):  Data matrix
 C
 cc      REAL*8  X(MJ1,1), Z(1)
 cxx      REAL*8  X(MJ1,K+1), Z(N0+L+K)
-      INTEGER :: N0, L, K, MJ1, JSW
-      REAL(8) :: Z(N0+L+K), X(MJ1,K+1)
+      INTEGER N0, L, K, MJ1, JSW
+      DOUBLE PRECISION Z(N0+L+K), X(MJ1,K+1)
 C
       I0 = 0
       IF( JSW .EQ. 1 )     I0 = K+1
@@ -502,10 +457,10 @@ C
 cxx      IMPLICIT REAL*8 (A-H,O-Z)
 cxx      DIMENSION  C(0:MAXM), SIG2(0:MAXM), AIC(0:MAXM)
 cxx      DIMENSION  PARCOR(MAXM), A(MAXM,MAXM)
-      INTEGER :: N, MAXM, MAR
-      REAL(8) :: C(0:MAXM), SIG2(0:MAXM), AIC(0:MAXM), PARCOR(MAXM),
-     1           A(MAXM,MAXM)
-      REAL(8) :: CONST, AICMIN, SUM
+      INTEGER N, MAXM, MAR
+      DOUBLE PRECISION C(0:MAXM), SIG2(0:MAXM), AIC(0:MAXM),
+     1                 PARCOR(MAXM), A(MAXM,MAXM)
+      DOUBLE PRECISION CONST, AICMIN, SUM
 C
       CONST = N*(DLOG(2*3.1415926535D0) + 1)
 C
@@ -559,9 +514,9 @@ cxx      IMPLICIT REAL*8(A-H,O-Z)
 cxx      DIMENSION A(M), B(L)
 cc      DIMENSION SP(0:NF), H(0:500), FR(0:500), FI(0:500)
 cxx      DIMENSION SP(0:NF), H(0:M+L), FR(0:NF), FI(0:NF)
-      INTEGER :: M, L, NF
-      REAL(8) :: A(M), B(L), SIG2, SP(0:NF)
-      REAL(8) :: H(0:M+L), FR(0:NF), FI(0:NF)
+      INTEGER M, L, NF
+      DOUBLE PRECISION A(M), B(L), SIG2, SP(0:NF)
+      DOUBLE PRECISION H(0:M+L), FR(0:NF), FI(0:NF)
 C
       H(0) = 1.0D0
       DO 10 I=1,M
@@ -611,9 +566,9 @@ C        FS(J):  Fourier sine transform   (J=1,M)
 C
 cxx      IMPLICIT REAL*8 (A-H,O-Z)
 cxx      DIMENSION  X(N), FC(M), FS(M)
-      INTEGER :: N, M
-      REAL(8) :: X(N), FC(M), FS(M)
-      REAL(8) :: PI, W, CI, SI, T0, T1, T2
+      INTEGER N, M
+      DOUBLE PRECISION X(N), FC(M), FS(M)
+      DOUBLE PRECISION PI, W, CI, SI, T0, T1, T2
       DATA  PI/3.14159265358979D0/
 C
       W = PI/(M-1)
@@ -648,8 +603,8 @@ C       VAR:    variance
 C
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cxx      DIMENSION  Y(N)
-      INTEGER :: N
-      REAL(8) :: Y(N), YMEAN, VAR, SUM
+      INTEGER N
+      DOUBLE PRECISION Y(N), YMEAN, VAR, SUM
 C
       SUM = 0.0D0
       DO 10 I=1,N
@@ -700,11 +655,12 @@ cxx      DIMENSION  XS(M), VS(M,M), VP(M,M)
 cxx      DIMENSION  XFS(M,NDIM), XPS(M,NDIM), XSS(M,NDIM)
 cxx      DIMENSION  VFS(M,M,NDIM), VPS(M,M,NDIM), VSS(M,M,NDIM)
 cxx      DIMENSION  WRK(M,M), SGAIN(M,M)
-      INTEGER :: M, NDIM, NS, NFE, NPE
-      REAL(8) :: F(M,M), VFS(M,M,NDIM), VPS(M,M,NDIM), XFS(M,NDIM),
-     1           XPS(M,NDIM), VSS(M,M,NDIM), XSS(M,NDIM)
-      REAL(8) :: XS(M), VS(M,M), VP(M,M), WRK(M,M), SGAIN(M,M), VDET,
-     1           SUM
+      INTEGER M, NDIM, NS, NFE, NPE
+      DOUBLE PRECISION F(M,M), VFS(M,M,NDIM), VPS(M,M,NDIM),
+     1                 XFS(M,NDIM), XPS(M,NDIM), VSS(M,M,NDIM),
+     2                 XSS(M,NDIM)
+      DOUBLE PRECISION XS(M), VS(M,M), VP(M,M), WRK(M,M), SGAIN(M,M),
+     1                 VDET, SUM
 C
 C
 C  ...  SMOOTHING  ...
@@ -861,8 +817,8 @@ C
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cc      DIMENSION  A(MJ,MJ), IND(50)
 cxx      DIMENSION  A(M,M), IND(M+1)
-      INTEGER :: M, IND(M+1)
-      REAL(8) :: A(M,M), DET, EPS, AMAX, SUM
+      INTEGER M, IND(M+1)
+      DOUBLE PRECISION A(M,M), DET, EPS, AMAX, SUM
 C
       EPS = 1.0D-10
 C
@@ -981,9 +937,9 @@ cc      DIMENSION  YMEAN(MJ1), NSUM(10)
 cxx      DIMENSION  Y(N,ID), OUTMIN(ID), OUTMAX(ID)
 cxx      DIMENSION  C(0:LAG,ID,ID), R(0:LAG,ID,ID)
 cxx      DIMENSION  YMEAN(ID), NSUM(ID)
-      INTEGER :: N, ID, LAG, NSUM(ID)
-      REAL(8) :: Y(N,ID), OUTMIN(ID), OUTMAX(ID), C(0:LAG,ID,ID),
-     1           R(0:LAG,ID,ID), YMEAN(ID), SUM
+      INTEGER N, ID, LAG, NSUM(ID)
+      DOUBLE PRECISION Y(N,ID), OUTMIN(ID), OUTMAX(ID), C(0:LAG,ID,ID),
+     1                 R(0:LAG,ID,ID), YMEAN(ID), SUM
 C
       DO 10 J=1,ID
 cxx   10 CALL  MEAN( Y(1,J),N,OUTMIN(J),OUTMAX(J),NSUM(J),YMEAN(J) )
@@ -1041,8 +997,8 @@ C        YMEAN:   sample mean
 C
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cxx      DIMENSION Y(N)
-      INTEGER :: N, NSUM
-      REAL(8) :: Y(N), OUTMIN, OUTMAX, YMEAN, YSUM
+      INTEGER N, NSUM
+      DOUBLE PRECISION Y(N), OUTMIN, OUTMAX, YMEAN, YSUM
 C
       NSUM = 0
       YSUM = 0.0D0
@@ -1068,8 +1024,8 @@ C        R(I):    sample autocorrelation
 C
 cxx      IMPLICIT REAL*8 (A-H,O-Z)
 cxx      DIMENSION  C(0:MAXLAG), R(0:MAXLAG)
-      INTEGER :: MAXLAG
-      REAL(8) :: C(0:MAXLAG), R(0:MAXLAG)
+      INTEGER MAXLAG
+      DOUBLE PRECISION C(0:MAXLAG), R(0:MAXLAG)
 C
       DO 10 LAG=0,MAXLAG
 cxx   10 R(LAG) = C(LAG)/C(0)
@@ -1093,8 +1049,8 @@ C        C(I):    autocovariance function
 C
 cxx      IMPLICIT REAL*8( A-H,O-Z )
 cxx      DIMENSION Y(N), C(0:MAXLAG )
-      INTEGER :: N, MAXLAG
-      REAL(8) :: Y(N), OUTMIN, OUTMAX, C(0:MAXLAG ), YMEAN, SUM
+      INTEGER N, MAXLAG
+      DOUBLE PRECISION Y(N), OUTMIN, OUTMAX, C(0:MAXLAG ), YMEAN, SUM
 C
 C  ...  sample mean  ...
 C
@@ -1138,8 +1094,8 @@ C                     = 4   error bound for sample autocorrelation
 C
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cxx      DIMENSION  Y(N), COV(0:MAXLAG,4)
-      INTEGER :: N, MAXLAG
-      REAL(8) :: Y(N), OUTMIN, OUTMAX, COV(0:MAXLAG,4), YMEAN
+      INTEGER N, MAXLAG
+      DOUBLE PRECISION Y(N), OUTMIN, OUTMAX, COV(0:MAXLAG,4), YMEAN
 C
 C  ...  sample autocovariance function  ...
 C
@@ -1171,8 +1127,8 @@ C        RERR(I):  error bound for I-th autocorrelation
 C
 cxx      IMPLICIT REAL*8 (A-H,O-Z)
 cxx      DIMENSION  C(0:MAXLAG), CERR(0:MAXLAG), RERR(0:MAXLAG)
-      INTEGER :: N, MAXLAG
-      REAL(8) :: C(0:MAXLAG), CERR(0:MAXLAG), RERR(0:MAXLAG), SUM
+      INTEGER N, MAXLAG
+      DOUBLE PRECISION C(0:MAXLAG), CERR(0:MAXLAG), RERR(0:MAXLAG), SUM
 C
       SUM = C(0)**2
       CERR(0)   = DSQRT( 2*SUM/N )
@@ -1206,8 +1162,8 @@ C
 cxx      IMPLICIT  REAL*8(A-H,O-Z)
 cxx      DIMENSION  PE(0:NP), SPE(0:NP)
 cxx      DIMENSION  W(0:1,2)
-      INTEGER :: NP, IWINDW, IFG
-      REAL(8) ::PE(0:NP), SPE(0:NP), W(0:1,2), PMIN
+      INTEGER NP, IWINDW, IFG
+      DOUBLE PRECISIONPE(0:NP), SPE(0:NP), W(0:1,2), PMIN
       DATA  W/0.5D0, 0.25D0, 0.54D0, 0.23D0/
 C
       IF( IWINDW.EQ.0 )  THEN
@@ -1265,9 +1221,9 @@ C
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cc      DIMENSION  F(MJ,MJ), G(MJ,MJ), H(MJ), Q(MJ,MJ), AR(*), R(1,1)
 cxx      DIMENSION  F(M,M), G(M,K), H(M), Q(K,K), AR(M3), R(1,1)
-      INTEGER :: M1, M2, M3, IPER, M, K 
-      REAL(8) :: AR(M3), TAU1, TAU2, TAU3, SIG2, F(M,M), G(M,K), H(M),
-     1           Q(K,K), R(1,1)
+      INTEGER M1, M2, M3, IPER, M, K 
+      DOUBLE PRECISION AR(M3), TAU1, TAU2, TAU3, SIG2, F(M,M), G(M,K),
+     1                 H(M), Q(K,K), R(1,1)
 C
 cc      M = M1 + M2*(IPER-1) + M3
 cc      K = ID(M1) + ID(M2) + ID(M3)
@@ -1352,8 +1308,8 @@ C        Y(I,J):   LOWER TRIANGULAR MATRIX; X = Y*Y'
 C
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cxx      DIMENSION  X(MJ,MJ), Y(NJ,NJ)
-      INTEGER :: MJ, N, NJ
-      REAL(8) :: X(MJ,MJ), Y(NJ,NJ), SUM1, SUM2
+      INTEGER MJ, N, NJ
+      DOUBLE PRECISION X(MJ,MJ), Y(NJ,NJ), SUM1, SUM2
 C
 cxx      DO 10 I=1,N
 cxx      DO 10 J=1,N
@@ -1401,9 +1357,9 @@ cc      DIMENSION  A(*), B(*), COV(0:K), G(0:100), X(30,30)
 cc      DIMENSION  Z(100), UL(30,30), IPS(100)
 cxx      DIMENSION  A(M), B(L), COV(0:K), G(0:KMAX), X(M+1,M+1)
 cxx      DIMENSION  Z(M+1), UL(M+1,M+1), IPS(M+1)
-      INTEGER :: M, L, K, KMAX, IER, IPS(M+1)
-      REAL(8) :: A(M), B(L), SIG2, COV(0:K)
-      REAL(8) :: G(0:KMAX), X(M+1,M+1), Z(M+1), UL(M+1,M+1), SUM
+      INTEGER M, L, K, KMAX, IER, IPS(M+1)
+      DOUBLE PRECISION A(M), B(L), SIG2, COV(0:K)
+      DOUBLE PRECISION G(0:KMAX), X(M+1,M+1), Z(M+1), UL(M+1,M+1), SUM
 C
 cc      KMAX = MAX(M,L,K)
       CALL  IMPULS( M,L,A,B,KMAX,G )
@@ -1510,8 +1466,9 @@ C
 cxx      IMPLICIT REAL*8(A-H,O-Z )
 cc      DIMENSION A(MJ,*),UL(MJ,*),SCALES(100),IPS(100)
 cxx      DIMENSION A(N,N),UL(N,N),SCALES(N),IPS(N)
-      INTEGER :: N, IPS(N), IER
-      REAL(8) :: A(N,N), UL(N,N), SCALES(N), RNORM, BIG, SIZE, PIVOT, TM
+      INTEGER N, IPS(N), IER
+      DOUBLE PRECISION A(N,N), UL(N,N), SCALES(N), RNORM, BIG, SIZE,
+     1                 PIVOT, TM
 C
       IER = 0
 C
@@ -1591,8 +1548,8 @@ C     Y.I.
 cxx      IMPLICIT REAL*8( A-H,O-Z )
 cc      DIMENSION A(*), B(*), G(0:K)
 cxx      DIMENSION A(M), B(L), G(0:K)
-      INTEGER :: M, L, K
-      REAL(8) :: A(M), B(L), G(0:K), SUM
+      INTEGER M, L, K
+      DOUBLE PRECISION A(M), B(L), G(0:K), SUM
 C
       G(0) = 1.0
       DO  20 I=1,K
@@ -1626,8 +1583,8 @@ C     Y.I.
 cxx      IMPLICIT REAL*8( A-H,O-Z )
 cc      DIMENSION UL(MJ,*),B(*),X(*),IPS(100)
 cxx      DIMENSION UL(N,N),B(N),X(N),IPS(N)
-      INTEGER :: N, IPS(N)
-      REAL(8) :: UL(N,N), B(N),X(N), SUM
+      INTEGER N, IPS(N)
+      DOUBLE PRECISION UL(N,N), B(N),X(N), SUM
 C
       DO 20 I=1,N
       SUM = 0.0D0
@@ -1688,12 +1645,12 @@ cxx      DIMENSION  XFS(MJ,NMAX), XPS(MJ,NMAX), XSS(MJ,NMAX)
 cxx      DIMENSION  VFS(MJ,MJ,NMAX), VPS(MJ,MJ,NMAX), VSS(MJ,MJ,NMAX)
 cxx      DIMENSION  WRK(MJ,MJ), SGAIN(MJ,MJ)
 cxx      DIMENSION  I0(NC)
-      INTEGER :: MMAX, NC, N S, N, NE, NMAX, MJ, M(NC), I0(NC)
-      REAL(8) :: A(MMAX,NC), VFS(MJ,MJ,NMAX), VPS(MJ,MJ,NMAX),
-     1           VSS(MJ,MJ,NMAX), XFS(MJ,NMAX), XPS(MJ,NMAX),
-     2           XSS(MJ,NMAX)
-      REAL(8) :: XS(MJ), VS(MJ,MJ), VP(MJ,MJ), WRK(MJ,MJ), SGAIN(MJ,MJ),
-     1           SUM, VDET
+      INTEGER MMAX, NC, N S, N, NE, NMAX, MJ, M(NC), I0(NC)
+      DOUBLE PRECISION A(MMAX,NC), VFS(MJ,MJ,NMAX), VPS(MJ,MJ,NMAX),
+     1                 VSS(MJ,MJ,NMAX), XFS(MJ,NMAX), XPS(MJ,NMAX),
+     2                 XSS(MJ,NMAX)
+      DOUBLE PRECISION XS(MJ), VS(MJ,MJ), VP(MJ,MJ), WRK(MJ,MJ),
+     1                 SGAIN(MJ,MJ), SUM, VDET
 C
       I0(1) = 0
       DO 10 I=2,NC
@@ -1855,7 +1812,7 @@ C
       E N D                                                             
 
       SUBROUTINE INIT(IX)
-      INTEGER :: IX, v(8)
+      INTEGER IX, v(8)
 C
       if ( IX .ge. 0 ) then
           call init_genrand64(IX)
@@ -1879,7 +1836,7 @@ C        GAUSS:     density at X
 C
 cxx      IMPLICIT  REAL*8(A-H,O-Z)
 cxx      DIMENSION  PARAM(2)
-      REAL(8) :: X, PARAM(2), C1
+      DOUBLE PRECISION X, PARAM(2), C1
       DATA  C1  /2.506628275D0/
 C
       GAUSS = DEXP( -(X-PARAM(1))**2/(2*PARAM(2)) )/(C1*DSQRT(PARAM(2)))
@@ -1899,7 +1856,7 @@ C        PEARSN:    density at X
 C
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cxx      DIMENSION  PARAM(3)
-      REAL(8) :: X, PARAM(3), PI, dgammafn
+      DOUBLE PRECISION X, PARAM(3), PI, dgammafn
       DATA  PI/3.1415926535D0/
 C
 CXX      PEARSN = DGAMMA(PARAM(3))/DGAMMA(PARAM(3)-0.5D0)
@@ -1921,7 +1878,7 @@ C        DBLEXP:    density at X
 C
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cxx      dimension PARAM(3)
-      REAL(8) :: X, PARAM(3)
+      DOUBLE PRECISION X, PARAM(3)
 C
 cxx 2018/07/02      DBLEXP = DEXP( X-DEXP(X) )
       DBLEXP = DEXP( (X-PARAM(1))-DEXP(X-PARAM(1)) )
@@ -1942,7 +1899,7 @@ C        CAUCHY:    density at X
 C
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cxx      DIMENSION  PARAM(2)
-      REAL(8) :: X, PARAM(2), PI
+      DOUBLE PRECISION X, PARAM(2), PI
       DATA  PI /3.1415926535D0/
 C
       CAUCHY = DSQRT( PARAM(2) )/(PARAM(2) + (X-PARAM(1))**2)/PI
